==> pass_mtx-0.0.20.tar.gz: ios/Frameworks/pass_mtx_ios.xcframework/ios-arm64_arm64e/Headers/pass_mtx_ios.h <==
/*
#################################################################################
#                                                                               #
#                     COPYRIGHT (C) DATABANK LLC since 2017                     #
#                                                                               #
#          ALL RIGHTS RESERVED BY DATABANK LLC.  THIS PROGRAM MUST BE           #
#          USED SOLELY FOR THE PURPOSES OF DATABANK LLC AND ITS USERS.          #
#   NO PART OF THIS PROGRAM MAY BE MODIFIED IN SOURCE OR BINARY FORM BY OTHERS  #
#             WITHOUT THE PRIOR WRITTEN PERMISSION OF DATABANK LLC.             #
#                                                                               #
#     USE OF COPYRIGHT NOTICE DOES NOT EVIDENCE PUBLICATION OF THE PROGRAM.     #
#                                                                               #
#################################################################################
*/

#import <Foundation/Foundation.h>


// NS_ASSUME_NONNULL_BEGIN

@interface PassMtxIOSWrapper : NSObject

- (NSString*)ping;
- (NSString*)passInit:(NSString *)app_id client_id:(NSString *)client_id private_pem:(NSString *)private_pem public_pem:(NSString *)public_pem;
- (NSString*)passStageInit:(NSString *)app_id client_id:(NSString *)client_id private_pem:(NSString *)private_pem public_pem:(NSString *)public_pem;
- (NSString*)getDLLVersion;
- (NSString*)PassGetCard:(NSString *)user_id;
- (NSString*)PassDeleteCard:(NSString *)user_id;
- (NSString*)PassSaveCard:(NSString *)user_id card_pan:(NSString *)card_pan cvv:(NSString *)cvv exp_date:(NSString *)exp_date card_holder_name:(NSString *)card_holder_name;
- (NSString*)PassVerifyCard:(NSString *)user_id verification_method:(NSString *)verification_method verification_value:(NSString *)verification_value;
- (NSString*)PassPurchase:(NSString *)user_id order_id:(NSString *)order_id payment_token:(NSString *)payment_token payment_amount:(NSString *)payment_amount expire_date:(NSString *)expire_date db_ref_no:(NSString *)db_ref_no description:(NSString *)description ;


- (NSString*)PassGetQr:(NSString *)user_id order_id:(NSString *)order_id payment_token:(NSString *)payment_token expire_date:(NSString *)expire_date ttl:(NSString *)ttl;
- (NSString*)PassOrderInquery:(NSString *)user_id order_id:(NSString *)order_id ;
- (NSString*)PassOrderConfirm:(NSString *)user_id order_id:(NSString *)order_id  confirm_method:(NSString *)confirm_method confirm_result:(NSString *)confirm_result ;
- (NSString*)PassOrderCancel:(NSString *)user_id order_id:(NSString *)order_id;

@end


// NS_ASSUME_NONNULL_END

==> pass_mtx-0.0.23.tar.gz: ios/Frameworks/pass_mtx_ios.xcframework/ios-arm64_arm64e/Headers/pass_mtx_ios.h <==
/*
#################################################################################
#                                                                               #
#                     COPYRIGHT (C) DATABANK LLC since 2017                     #
#                                                                               #
#          ALL RIGHTS RESERVED BY DATABANK LLC.  THIS PROGRAM MUST BE           #
#          USED SOLELY FOR THE PURPOSES OF DATABANK LLC AND ITS USERS.          #
#   NO PART OF THIS PROGRAM MAY BE MODIFIED IN SOURCE OR BINARY FORM BY OTHERS  #
#             WITHOUT THE PRIOR WRITTEN PERMISSION OF DATABANK LLC.             #
#                                                                               #
#     USE OF COPYRIGHT NOTICE DOES NOT EVIDENCE PUBLICATION OF THE PROGRAM.     #
#                                                                               #
#################################################################################
*/

#import <Foundation/Foundation.h>


// NS_ASSUME_NONNULL_BEGIN

@interface PassMtxIOSWrapper : NSObject

- (NSString*)ping;
- (NSString*)passInit:(NSString *)app_id client_id:(NSString *)client_id private_pem:(NSString *)private_pem public_pem:(NSString *)public_pem;
- (NSString*)passStageInit:(NSString *)app_id client_id:(NSString *)client_id private_pem:(NSString *)private_pem public_pem:(NSString *)public_pem;
- (NSString*)getDLLVersion;
- (NSString*)PassGetCard:(NSString *)user_id;
- (NSString*)PassDeleteCard:(NSString *)user_id card_ref:(NSString *)card_ref;
- (NSString*)PassSaveCard:(NSString *)user_id card_pan:(NSString *)card_pan cvv:(NSString *)cvv exp_date:(NSString *)exp_date card_holder_name:(NSString *)card_holder_name;
- (NSString*)PassVerifyCard:(NSString *)user_id verification_method:(NSString *)verification_method verification_value:(NSString *)verification_value;
- (NSString*)PassPurchase:(NSString *)user_id order_id:(NSString *)order_id payment_token:(NSString *)payment_token payment_amount:(NSString *)payment_amount expire_date:(NSString *)expire_date db_ref_no:(NSString *)db_ref_no description:(NSString *)description ;


- (NSString*)PassGetQr:(NSString *)user_id order_id:(NSString *)order_id payment_token:(NSString *)payment_token expire_date:(NSString *)expire_date ttl:(NSString *)ttl;
- (NSString*)PassOrderInquery:(NSString *)user_id order_id:(NSString *)order_id ;
- (NSString*)PassOrderConfirm:(NSString *)user_id order_id:(NSString *)order_id  confirm_method:(NSString *)confirm_method confirm_result:(NSString *)confirm_result payment_token:(NSString *)payment_token expire_date:(NSString *)expire_date ;
- (NSString*)PassOrderCancel:(NSString *)user_id order_id:(NSString *)order_id;

@end


// NS_ASSUME_NONNULL_END
